@@ -361,11 +361,13 @@ def test_parse_depot_domain_with_numeric_actions_succeeds_in_parsing_all_domain_
     assert len(domain.actions) == 5
 
 
-def test_parse_action_with_function_equality_precondition_sets_a_new_numeric_precondition(domain_parser: DomainParser):
+def test_parse_action_with_function_equality_precondition_sets_a_new_numeric_precondition():
     domain_parser = DomainParser(PLANT_WATERING_DOMAIN)
     domain = domain_parser.parse_domain()
     assert domain is not None
     assert len(domain.actions) == 10
     assert len(domain.actions["pour"].numeric_preconditions) == 5
-    for numeric_precond in domain.actions["pour"].numeric_preconditions:
-        print(str(numeric_precond))
\ No newline at end of file
+    for action in domain.actions.values():
+        print(action.name)
+        for numeric_precond in action.numeric_preconditions:
+            print(str(numeric_precond))
\ No newline at end of file
